# -*- coding: utf-8 -*-

import os
import logging
from config import config
from pymyorm.database import Database
from app.helper.functions import create_log


class BaseCommand(object):

    log_file_name = 'console.log'

    def __init__(self):
        config_name = os.environ.get('FLASK_APP_CONFIG', 'development')
        conf = config[config_name]
        self.conf = conf
        self.base_path = conf.BASE_PATH
        self.create_log()
        self.connect()

    def create_log(self):
        log_dir = os.path.join(self.base_path, 'log')
        if not os.path.exists(log_dir):
            os.mkdir(log_dir)
        log_file = os.path.join(log_dir, self.log_file_name)
        create_log(log_file)

    def connect(self):
        try:
            mysql_conf = self.conf.MYSQL_CONF
            Database.connect(**mysql_conf)
        except Exception as e:
            logging.error(str(e))



# -*- coding: utf-8 -*-

from flask import request, render_template, current_app as app
import json
import math


class BaseController(object):

    OK = 0
    ERROR = 1

    def __init__(self):
        self.conf = app.config
        self.redis = app.config['redis']
        self.page = 0
        self.offset = 0
        self.limit = 0

    @staticmethod
    def ok(data, code=OK):
        return dict(code=code, data=data)

    @staticmethod
    def error(data, code=ERROR):
        return dict(code=code, data=data)

    @staticmethod
    def get(name):
        return request.args.get(name)

    @staticmethod
    def post(name):
        return request.json.get(name)

    @staticmethod
    def render(template, data=None):
        if data is None:
            return render_template(template)
        else:
            return render_template(template, **data)

    def init_page(self):
        self.page = int(request.args.get('page', 1))
        self.limit = int(request.args.get('limit', 10))
        self.offset = (self.page - 1) * self.limit

    def resp_list(self, all, total):
        total_page = math.ceil(total / self.limit)
        data = dict(
            list=all,
            page=self.page,
            limit=self.limit,
            total=total,
            total_page=total_page
        )
        return self.ok(data)

    def get_current_user(self):
        token = request.headers.get('Token')
        user = self.redis.get(token)
        return json.loads(user)



# -*- coding: utf-8 -*-

from app.base import app
from app.helper.router import Router


router = Router(app=app)
router.add('/', 'index/index')
router.add('/test/<name>', 'test/hello')

admin = Router(app=app, subdomain='admin', module='admin')
admin.add('/', 'index/index')

user = Router(app=app, subdomain='user', module='user/test')
user.add('/', 'index/index')



#!/usr/bin/env python
from setuptools import setup, find_packages

version = '0.0.6'

with open("./README.md", encoding="utf-8") as f:
    readme = f.read()

setup(
    name="Hallo",
    version=version,
    url='https://github.com/oldjun/hallo',
    author='JP Chen',
    author_email='oldjun@sina.com',
    description='web mvc framework for python',
    long_description=readme,
    long_description_content_type='text/markdown',
    python_requires=">=3.6",
    install_requires=[
    ],
    license="MIT",
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Topic :: Database',
    ],
    entry_points={
        'console_scripts': ['hallo=hallo.__main__:main'],
    },
    include_package_data=True
)



# -*- coding: utf-8 -*-

from app.module.base import BaseController


class IndexController(BaseController):

    def index(self):
        tv = dict()
        tv['brief'] = 'Life is short, use python'
        return self.render('index/index.html', tv)



# -*- coding: utf-8 -*-

from importlib import import_module


class Console(object):
    def __init__(self):
        pass

    @staticmethod
    def run(command, **kwargs):
        module, action = command.split('/')
        if action.startswith('_'):
            raise Exception(f'protected function is not allowed:{action}')
        try:
            ctrl_list = [ctrl for ctrl in module.split('_')]
            ctrl_file = '_'.join([ctrl for ctrl in ctrl_list])
            m = import_module(f'app.console.{ctrl_file}')
            ctrl_class = ''.join([ctrl.capitalize() for ctrl in ctrl_list])
            c = getattr(m, ctrl_class + 'Command')
            f = getattr(c(), action)
        except Exception as e:
            print(str(e))
            raise e
        f(**kwargs)



# -*- coding: utf-8 -*-

import hashlib
import time
from logging.config import dictConfig


def ok(data='ok'):
    return dict(code=0, data=data)


def error(data='error', code=1):
    return dict(code=code, data=data)


def create_token(userid):
    md5 = hashlib.md5()
    md5.update(str(time.time()).encode('utf-8'))
    md5.update(userid.encode('utf-8'))
    return md5.hexdigest()


def create_log(log_file):
    dictConfig({
        'version': 1,
        'formatters': {
            'default': {
                'format': '%(asctime)s %(levelname)s [%(filename)s:%(lineno)s]: %(message)s',
                'datefmt': '%Y-%m-%d %H:%M:%S'
            }
        },
        'handlers': {
            'wsgi': {
                'class': 'logging.StreamHandler',
                'stream': 'ext://flask.logging.wsgi_errors_stream',
                'formatter': 'default'
            },
            'message': {
                'class': 'logging.handlers.RotatingFileHandler',
                'formatter': 'default',
                'filename': log_file,
                'maxBytes': 1024 * 1024,
                'backupCount': 10,
                'encoding': 'utf-8'
            }
        },
        'root': {
            'level': 'INFO',
            'handlers': ['wsgi', 'message']
        }
    })
